@@ -11,15 +11,15 @@ has name => (is => 'ro', default => 'TEL', isa => 'Str' );
 
 subtype 'Tel'
     => as 'Str'
-    => where { m/^(:?[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,3}[\s\-]?\d{3,4}$/s }
+    => where { m/^(?:[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,4}[\s\-]?\d{3,4}$/s }
     => message { "The Number you provided, $_, was not supported in Tel" };
 has content => (is => 'ro', default => '', isa => 'Tel' );
 
 subtype 'TelType'
     => as 'Str'
     => where {
-        m/^(:?work|home)$/is or #common
-        m/^(:?text|voice|fax|cell|video|pager|textphone)$/is # for tel
+        m/^(?:work|home)$/is or #common
+        m/^(?:text|voice|fax|cell|video|pager|textphone)$/is # for tel
     }
     => message { "The text you provided, $_, was not supported in 'TelType'" };
 has types => ( is => 'rw', isa => 'ArrayRef[Maybe[TelType]]');
@@ -32,8 +32,9 @@ override 'as_string' => sub {
     push @lines, 'PID=' . join ',', @{ $self->pid } if $self->can('pid') and $self->pid;
     push @lines, 'TYPE=' . join( ',', map { uc $_ } @{ $self->types } ) if @{ $self->types || [] } > 0;
 
-    ( my $content = $self->content ) =~ s/[-+()\s]+/ /sg;
-    $content =~ s/^ //s;
+    ( my $content = $self->content ) =~ s/^ //s;    # remove top space
+    $content =~ s/(?:(?!\A)\D|\()+/ /sg;            # replace symbols to space
+    $content =~ s/^ //s;                            # remove top space again
     my $string = join(';', @lines ) . ':' . $content;
     return $self->fold( $string, -force => 1 );
 };
